==> vtigercrm-5.3.0p0.tgz: modules/com_vtiger_workflow/language/pt_br.lang.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger. All Rights Reserved.
 * Contributor(s): Valmir Carlos Trindade/Translate to Brazilian Portuguese|14/10/2011|Curitiba/Paraná/Brasil.|www.ttcasolucoes.com.br
  ************************************************************************************/
$mod_strings = array(
'VTEmailTask' => 'Enviar Email',
'VTEntityMethodTask' => 'Invocar Função Customizada',
'VTCreateTodoTask' => 'Criar Compromisso',
'VTCreateEventTask' => 'Criar Evento',
'VTSMSTask' => 'Tarefa SMS',
'LBL_EDIT_TASK'=>'Editar Tarefa',
'LBL_EDIT_TASK_TITLE'=>'Editar uma Tarefa existente ou criar nova',
'LBL_EDIT_WORKFLOW'=>'Editar Workflow',
'LBL_EDIT_WORKFLOW_TITLE'=>'Editar um Workflow existente ou criar novo',
'LBL_FROM_TEMPLATE'=>'Do Modelo',
'LBL_NEW_WORKFLOW'=>'Novo Workflow',
'LBL_NEW_TEMPLATE'=>'Salvar como Modelo',
'LBL_CREATE_WORKFLOW_FOR'=>'Criar um Workflow para',
'LBL_FOR_MODULE'=>'Para Módulo',
'LBL_CHOOSE_A_TEMPLATE'=>'Escolher um Modelo',
'LBL_VALIDATION_MISSING_MANDATORY_FIELDS'=>'Existe um campo obrigatório vazio.',
'LBL_VALIDATION_INVALID_DATE_RANGE'=>'A data/hora Inicial é maior do que a data/hora final',
'LBL_ERROR_NO_WORKFLOW'=>'O Workflow solicitado não existe',
'LBL_ERROR_NO_TASK'=>'A Tarefa solicitada não existe',
'LBL_ERROR_NOT_ADMIN'=>'Você não tem acesso a este Módulo visto que você não é um usuário admin',
'LBL_CREATE_WORKFLOW'=>'Criar workflow',
'LBL_WORKFLOW_LIST'=>'Lista Workflow',
'LBL_AVAILABLE_WORKLIST_LIST'=>'Workflows Disponíveis',
'LBL_LOADING'=>'Carregando...',
'LBL_VALIDATION_ERROR'=>'Erro Validação',
'LBL_SELECT_OPTION_DOTDOTDOT'=>'Selecionar Opção...',
'LBL_WORKFLOW_NOTE_CRON_CONFIG'=>'NOTA: Você deve ter um script Cron configurado para o Workflow.',
'LBL_NO_TEMPLATES'=>'Nenhum Modelo',
'LBL_SELECT'=>'Selecionar',
'LBL_MESSAGE'=>'Mensagem',
'LBL_SET_FIELD_VALUES'=>'Configurar Valor Campos',
'LBL_ADD_FIELD'=>'Adicionar Campo',

'LBL_USE_FIELD_VALUE_DASHDASH'=>'-- Utilizar Valor Campo --',
'LBL_USE_FUNCTION_DASHDASH'=>'-- Utilizar Função --',

'LBL_RAW_TEXT'=>'Texto Puro',
'LBL_FIELD'=>'Campo',
'LBL_EXPRESSION'=>'Expressão',
'LBL_SET_EXPRESSION'=>'Configurar Expressão',

'LBL_MANUAL'=>'Sistema',

'LBL_NEW_CONDITION_GROUP_BUTTON_LABEL'=>'Novo Grupo Condição',

'VTUpdateFieldsTask' => 'Atualizar Campos',


'LBL_VALIDATION_DUPLICATE_FIELDNAMES' => 'Mesmo campo selecionado mais de uma vez.',
'LBL_VALIDATION_INVALID_FIELD_VALUES' => 'Valores de campo inválidos',
'LBL_CREATE_ENTITY_NOTE_ORDER_MATTERS' => 'Nota: As expressões serão avaliadas na ordem dos valores do campo fornecidos.
							    Portanto, certifique-se de que tenha fornecido o valor para um campo antes de utilizá-lo na expressão.',
'LBL_SET_VALUE' => 'Configurar Valor',

'LBL_EMAIL_RECIPIENT' => 'Destinatário',
'LBL_EMAIL_CC' => 'CC',
'LBL_EMAIL_BCC' => 'BCC',
'LBL_EMAIL_SUBJECT' => 'Assunto',

'LBL_WORKFLOW_NOTE_EVENT_TASK_TIMEZONE' => 'Nota: Toda a data, hora e informação recorrente configurada para o Evento,
													estarão relacionados com o time zone padrão, configurado no config.inc.php',

);


?>

==> vtigercrm-5.4.0.tgz: modules/com_vtiger_workflow/language/pt_br.lang.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger. All Rights Reserved.
 * Contributor(s): Valmir Carlos Trindade/Translate to Brazilian Portuguese| 03/03/2012 |Curitiba/Paraná/Brasil.|www.ttcasolucoes.com.br
  ************************************************************************************/
$mod_strings = array(
'VTEmailTask' => 'Enviar Email',
'VTEntityMethodTask' => 'Invocar Função Customizada',
'VTCreateTodoTask' => 'Criar Compromisso',
'VTCreateEventTask' => 'Criar Evento',
'VTSMSTask' => 'Tarefa SMS',
'LBL_EDIT_TASK'=>'Editar Tarefa',
'LBL_EDIT_TASK_TITLE'=>'Editar uma Tarefa existente ou criar nova',
'LBL_EDIT_WORKFLOW'=>'Editar Workflow',
'LBL_EDIT_WORKFLOW_TITLE'=>'Editar um Workflow existente ou criar novo',
'LBL_FROM_TEMPLATE'=>'Do Modelo',
'LBL_NEW_WORKFLOW'=>'Novo Workflow',
'LBL_NEW_TEMPLATE'=>'Salvar como Modelo',
'LBL_CREATE_WORKFLOW_FOR'=>'Criar um Workflow para',
'LBL_FOR_MODULE'=>'Para Módulo',
'LBL_CHOOSE_A_TEMPLATE'=>'Escolher um Modelo',
'LBL_VALIDATION_MISSING_MANDATORY_FIELDS'=>'Existe um campo obrigatório vazio.',
'LBL_VALIDATION_INVALID_DATE_RANGE'=>'A data/hora Inicial é maior do que a data/hora final',
'LBL_ERROR_NO_WORKFLOW'=>'O Workflow solicitado não existe',
'LBL_ERROR_NO_TASK'=>'A Tarefa solicitada não existe',
'LBL_ERROR_NOT_ADMIN'=>'Você não tem acesso a este Módulo visto que você não é um usuário admin',
'LBL_CREATE_WORKFLOW'=>'Criar workflow',
'LBL_WORKFLOW_LIST'=>'Lista Workflow',
'LBL_AVAILABLE_WORKLIST_LIST'=>'Workflows Disponíveis',
'LBL_LOADING'=>'Carregando...',
'LBL_VALIDATION_ERROR'=>'Erro Validação',
'LBL_SELECT_OPTION_DOTDOTDOT'=>'Selecionar Opção...',
'LBL_WORKFLOW_NOTE_CRON_CONFIG'=>'NOTA: Você deve ter um script Cron configurado para o Workflow.',
'LBL_NO_TEMPLATES'=>'Nenhum Modelo',
'LBL_SELECT'=>'Selecionar',
'LBL_MESSAGE'=>'Mensagem',
'LBL_SET_FIELD_VALUES'=>'Configurar Valor Campos',
'LBL_ADD_FIELD'=>'Adicionar Campo',

'LBL_USE_FIELD_VALUE_DASHDASH'=>'-- Utilizar Valor Campo --',
'LBL_USE_FUNCTION_DASHDASH'=>'-- Utilizar Função --',

'LBL_RAW_TEXT'=>'Texto Puro',
'LBL_FIELD'=>'Campo',
'LBL_EXPRESSION'=>'Expressão',
'LBL_SET_EXPRESSION'=>'Configurar Expressão',

'LBL_MANUAL'=>'Sistema',

'LBL_NEW_CONDITION_GROUP_BUTTON_LABEL'=>'Novo Grupo Condição',

'VTUpdateFieldsTask' => 'Atualizar Campos',


'LBL_VALIDATION_DUPLICATE_FIELDNAMES' => 'Mesmo campo selecionado mais de uma vez.',
'LBL_VALIDATION_INVALID_FIELD_VALUES' => 'Valores de campo inválidos',
'LBL_CREATE_ENTITY_NOTE_ORDER_MATTERS' => 'Nota: As expressões serão avaliadas na ordem dos valores do campo fornecidos.
							    Portanto, certifique-se de que tenha fornecido o valor para um campo antes de utilizá-lo na expressão.',
'LBL_SET_VALUE' => 'Configurar Valor',

'LBL_EMAIL_RECIPIENT' => 'Destinatário',
'LBL_EMAIL_CC' => 'CC',
'LBL_EMAIL_BCC' => 'BCC',
'LBL_EMAIL_SUBJECT' => 'Assunto',

'LBL_WORKFLOW_NOTE_EVENT_TASK_TIMEZONE' => 'Nota: Toda a data, hora e informação recorrente configurada para o Evento,
													estarão relacionados com o time zone padrão, configurado no config.inc.php',

'Select Meta Variables' => 'Selecionar Variáveis Meta',
'Current Date' => 'Data Atual',
'Current Time' => 'Hora Atual',
'System Timezone' => 'Sistema Fuso Horário [Timezone]',
'CRM Detail View URL' => 'Visualizar Detalhes URL do CRM',
'Portal Detail View URL' => 'Visualizar Detalhes URL do Portal',
'Site Url' => 'Url do Site',
'Portal Url' => 'Url do Portal',

'Workflow'=>'Workflow',

'VTCreateEntityTask' => 'Criar Entidade',
'LBL_ENTITY_TYPE' => 'Tipo Entidade',
'LBL_SELECT_ENTITY_TYPE' => '-- Selecionar Tipo Entidade --',
'LBL_NO_ENTITIES_FOUND' => 'Nenhuma Entidade Encontrada para ser Criar',
);


?>
